# Future works: 
- correct()
- Better support for parallel cores
- classification and regression

# 0.8.3 (todo)
- (todo) Make the "extract()" more flexible
- (todo) Integrate figures with labels into one
- (todo) classification across timepints and across trials
- (todo) roll_on_level on time and time_group

# 0.8.2.2 
- Now time-frequency supports the power difference between two conditions
- Fixed a issue when plot the heatmap

# 0.8.2 (2018-03-05)
- Removed 'time_group' index which are unnecessary in Analyzed_Result
- Refine X axis in figure
- Improved the compatibility of save() and load() of Analyzed_Result
- New algorithm 'frequency_topography()'. Now we can calculate the topography of frequency.
- New method 'convert()' in module 'Basic'

# 0.8.1 (2018-03-01)
- MASSIVE amount of changes
- Altered the package name to "easyEEG"

# 0.8 (2017-12-25)
- First to public release. Merry Xmax!